[![Pub Package](https://img.shields.io/pub/v/maps.svg)](https://pub.dev/packages/maps)
[![Github Actions CI](https://github.com/dint-dev/maps/workflows/Dart%20CI/badge.svg)](https://github.com/dint-dev/maps/actions?query=workflow%3A%22Dart+CI%22)

# Overview

Geographic maps for Flutter applications. Licensed under the [Apache License 2.0](LICENSE).

This package is:
  * __Cross-platform__
    * Android and iOS
    * Browsers
  * __Multi-vendor__
    * Apple
    * Bing
    * Google

This is an early-stage version and lots of things are still missing or broken.
Pull requests are welcome!

## Links
  * [Github project](https://github.com/dint-dev/maps)
  * [Issue tracker](https://github.com/dint-dev/maps/issues)
  * [Pub package](https://pub.dev/packages/maps)
  * [API reference](https://pub.dev/documentation/maps/latest/)

# Getting started
## 1.Add dependency
```yaml
dependencies:
  maps: ^0.2.0
```

## 2.Use
### MapAppLauncher
[MapAppLauncher](https://pub.dev/documentation/maps/latest/maps/MapAppLAuncher-class.html) launches
either:
  * A map website (such as Google Maps website)
  * A map application in the device (such as Google Maps for Android/iOS)

```dart
import 'package:maps/maps.dart';

Future<void> main() async {
  // Use default app
  await MapAppLauncher.defaultInstance.launch(query:'Eiffel Tower');

  // Use Google Maps
  await MapAppLauncher.googleMaps.launch(
    query:'Louvre Museum',
  );
}
```

### MapWidget
[MapWidget](https://pub.dev/documentation/maps/latest/maps/MapWidget-class.html) shows a map:
```dart
import 'package:flutter/material.dart';
import 'package:maps/maps.dart';

void main() {
  runApp(const MaterialApp(
    home: Scaffold(
      body: MapWidget(
        size: Size(300, 500),
        camera: MapCamera(
          query: 'Paris',
        ),
        markers: [
          MapMarker(
            query: 'Eiffel Tower',
          ),
        ],
        // Bing Maps iframe API does not necessarily require API credentials
        // so we use it in the example.
        adapter: MapAdapter.platformSpecific(
          android: GoogleMapsNativeAdapter(),
          browser: BingMapsIframeAdapter(),
          ios: AppleNativeAdapter(),
        ),
      ),
    ),
  ));
}
```

Assuming that you have enabled Flutter for Web, you can run:
```
flutter run -d chrome
```

# Recommended configuration file changes
## iOS
In `ios/Runner/Info.plist`:
```xml
	<key>io.flutter.embedded_views_preview</key>
	<true/>
	<key>Privacy - Location When In Use Usage Description</key>
	<string>A description of your privacy policy.</string>
```

# Supported map providers
## Apple Maps APIs
### iOS
  * [AppleMapsNativeAdapter](https://pub.dev/documentation/maps/latest/maps/AppleMapsNativeAdapter-class.html)
    enables you to use [Apple MapKit](https://developer.apple.com/documentation/mapkit).
    The current implementation depends on the Flutter package [apple_maps_flutter](https://pub.dev/packages/apple_maps_flutter),
    a package by a third-party developer.
  * The adapter doesn't require API credentials.
  * You need to edit `ios/Runner/Info.plist` (see "recommended configuration file changes").

### Javascript
  * [AppleMapsJsAdapter](https://pub.dev/documentation/maps/latest/maps/AppleMapsJsAdapter-class.html)
    enables you to uses [Apple MapKit JS](https://developer.apple.com/documentation/mapkitjs).
  * The adapter requires you to have API credentials (ECDSA P-256 key pair).

### Images
  * [AppleMapsStaticAdapter](https://pub.dev/documentation/maps/latest/maps/AppleMapsStaticAdapter-class.html)
    enables you to use [Apple Maps Web Snapshots API](https://developer.apple.com/documentation/snapshots).
  * The adapter requires you to have API credentials (ECDSA P-256 key pair).

## Bing Maps APIs
### Javascript
  * [BingMapsJsAdapter](https://pub.dev/documentation/maps/latest/maps/BingMapsJsAdapter-class.html)
    enables you to use [Bing Maps Javascript API](https://docs.microsoft.com/en-us/bingmaps/v8-web-control/).
  * The adapter requires an API key, which you can get at [Bing Maps API website](https://docs.microsoft.com/en-us/bingmaps/).

### Iframes
  * [BingMapsIframeAdapter](https://pub.dev/documentation/maps/latest/maps/BingMapsIframeAdapter-class.html)
    enables you to uses [Bing Maps Custom Map URLs](https://docs.microsoft.com/en-us/bingmaps/articles/create-a-custom-map-url).
  * Note that markers and many other features are unsupported by Bing Maps Custom Map URLs.
  * The adapter does NOT necessarily require an API key.

### Images
  * [BingMapsStaticAdapter](https://pub.dev/documentation/maps/latest/maps/BingMapsStaticAdapter-class.html)
    enables you to uses [Bing Maps REST API for static maps](https://docs.microsoft.com/en-us/bingmaps/rest-services/imagery/get-a-static-map).
  * The adapter requires an API key, which you can get at [Bing Maps API website](https://docs.microsoft.com/en-us/bingmaps/).

## Google Maps APIs
### Android / iOS
  * [GoogleMapsNativeAdapter](https://pub.dev/documentation/maps/latest/maps_adapter_google_maps/GoogleMapsNativeAdapter-class.html)
    enables you to use Google Map Android / iOS SDKs.
  * You need to obtain API keys and follow documentation by
    [google_maps_flutter](https://pub.dev/packages/google_maps_flutter).

### Javascript
  * [GoogleMapsJsAdapter](https://pub.dev/documentation/maps/latest/maps/GoogleMapsJsAdapter-class.html)
    enables you to use [Google Maps Javascript API](https://developers.google.com/maps/documentation/javascript/tutorial).
  * The adapter requires an API key, which you can get at [Google Maps API website](https://cloud.google.com/maps-platform/).

### Iframes
  * [GoogleMapsIframeAdapter](https://pub.dev/documentation/maps/latest/maps/GoogleMapsIframeAdapter-class.html)
     enables you to use [Google Maps Embed API](https://developers.google.com/maps/documentation/embed/guide).
  * Note that markers and many other features are unsupported by Google Maps Embed API.
  * The adapter requires an API key, which you can get at [Google Maps API website](https://cloud.google.com/maps-platform/).

### Images
  * [GoogleMapsStaticAdapter](https://pub.dev/documentation/maps/latest/maps/GoogleMapsStaticAdapter-class.html)
    enables you to use [Google Maps Static API](https://developers.google.com/maps/documentation/maps-static/intro).
  * The adapter requires an API key, which you can get at [Google Maps API website](https://cloud.google.com/maps-platform/).

# Tips
## Use images when you can
Static images are rendered identically in all platforms and have the best performance.
